@@ -13,7 +13,7 @@ extern "C" {
 
 
 /** Defines the Baresip version string */
-#define BARESIP_VERSION "3.18.0"
+#define BARESIP_VERSION "3.22.0"
 
 
 #ifndef NET_MAX_NS
@@ -236,6 +236,7 @@ bool call_has_video(const struct call *call);
 bool call_early_video_available(const struct call *call);
 bool call_refresh_allowed(const struct call *call);
 bool call_ack_pending(const struct call *call);
+bool call_sess_cmp(const struct call *call, const struct sip_msg *msg);
 int  call_transfer(struct call *call, const char *uri);
 int  call_replace_transfer(struct call *target_call, struct call *source_call);
 int  call_status(struct re_printf *pf, const struct call *call);
@@ -274,6 +275,8 @@ void call_set_media_direction(struct call *call, enum sdp_dir a,
 void call_set_mdir(struct call *call, enum sdp_dir a, enum sdp_dir v);
 void call_get_mdir(struct call *call, enum sdp_dir *ap, enum sdp_dir *vp);
 void call_set_media_estdir(struct call *call, enum sdp_dir a, enum sdp_dir v);
+void call_get_media_estdir(struct call *call,
+			   enum sdp_dir *ap, enum sdp_dir *vp);
 void call_start_answtmr(struct call *call, uint32_t ms);
 bool          call_supported(struct call *call, uint16_t tags);
 const char   *call_user_data(const struct call *call);
@@ -511,6 +514,8 @@ struct list     *contact_list(const struct contacts *contacts);
 const char      *contact_str(const struct contact *c);
 const char      *contact_uri(const struct contact *c);
 const char      *contact_presence_str(enum presence_status status);
+void             contact_get_ldir(const struct contact *c,
+				  enum sdp_dir *aup, enum sdp_dir *vidp);
 struct le       *contact_le(struct contact *cnt);
 void contacts_set_current(struct contacts *contacts, struct contact *cnt);
 struct contact *contacts_current(const struct contacts *contacts);
@@ -725,12 +730,24 @@ void log_enable_info(bool enable);
 void log_enable_stdout(bool enable);
 void log_enable_timestamps(bool enable);
 void log_enable_color(bool enable);
-void vlog(enum log_level level, const char *fmt, va_list ap);
-void loglv(enum log_level level, const char *fmt, ...);
-void debug(const char *fmt, ...);
-void info(const char *fmt, ...);
-void warning(const char *fmt, ...);
 
+#ifdef HAVE_RE_ARG
+#define loglv(level, fmt, ...)                                                \
+	_loglv(true, (level), (fmt), RE_VA_ARGS(__VA_ARGS__))
+#define debug(fmt, ...) _debug(true, (fmt), RE_VA_ARGS(__VA_ARGS__))
+#define info(fmt, ...) _info(true, (fmt), RE_VA_ARGS(__VA_ARGS__))
+#define warning(fmt, ...) _warning(true, (fmt), RE_VA_ARGS(__VA_ARGS__))
+#else
+#define loglv _loglv
+#define debug(...) _debug(false, __VA_ARGS__)
+#define info(...) _info(false, __VA_ARGS__)
+#define warning(...) _warning(false, __VA_ARGS__)
+#endif
+
+void _loglv(bool safe, enum log_level level, const char *fmt, ...);
+void _debug(bool safe, const char *fmt, ...);
+void _info(bool safe, const char *fmt, ...);
+void _warning(bool safe, const char *fmt, ...);
 
 /*
  * Menc - Media encryption (for RTP)
@@ -963,6 +980,7 @@ int  ua_call_alloc(struct call **callp, struct ua *ua,
 		   struct call *xcall, const char *local_uri,
 		   bool use_rtp);
 struct call *ua_find_call_state(const struct ua *ua, enum call_state st);
+struct call *ua_find_call_msg(struct ua *ua, const struct sip_msg *msg);
 int ua_raise(struct ua *ua);
 int ua_set_autoanswer_value(struct ua *ua, const char *value);
 void ua_add_extension(struct ua *ua, const char *extension);
